@@ -15,24 +15,32 @@ import json
 import logging
 import uuid
 from collections import deque
+from collections.abc import Sequence
 from dataclasses import dataclass
 from datetime import datetime
 from enum import Enum
 from typing import Any, Callable, Optional
 
 from awscrt import mqtt
+from awscrt.exceptions import AwsCrtError
 from awsiot import mqtt_connection_builder
 
 from .auth import NavienAuthClient
 from .config import AWS_IOT_ENDPOINT, AWS_REGION
 from .constants import (
+    CMD_ANTI_LEGIONELLA_DISABLE,
+    CMD_ANTI_LEGIONELLA_ENABLE,
     CMD_DEVICE_INFO_REQUEST,
     CMD_DHW_MODE,
     CMD_DHW_TEMPERATURE,
     CMD_ENERGY_USAGE_QUERY,
     CMD_POWER_OFF,
     CMD_POWER_ON,
+    CMD_RESERVATION_MANAGEMENT,
     CMD_STATUS_REQUEST,
+    CMD_TOU_DISABLE,
+    CMD_TOU_ENABLE,
+    CMD_TOU_SETTINGS,
 )
 from .events import EventEmitter
 from .models import (
@@ -40,6 +48,7 @@ from .models import (
     DeviceFeature,
     DeviceStatus,
     EnergyUsageResponse,
+    OperationMode,
 )
 
 __author__ = "Emmanuel Levijarvi"
@@ -49,6 +58,96 @@ __license__ = "MIT"
 _logger = logging.getLogger(__name__)
 
 
+def _redact(obj, keys_to_redact=None):
+    """Return a redacted copy of obj with sensitive keys masked.
+
+    This is a lightweight sanitizer for log messages to avoid emitting
+    secrets such as access keys, session tokens, passwords, emails,
+    clientIDs and sessionIDs.
+    """
+    if keys_to_redact is None:
+        keys_to_redact = {
+            "access_key_id",
+            "secret_access_key",
+            "secret_key",
+            "session_token",
+            "sessionToken",
+            "sessionID",
+            "clientID",
+            "clientId",
+            "client_id",
+            "password",
+            "pushToken",
+            "push_token",
+            "token",
+            "auth",
+            "macAddress",
+            "mac_address",
+            "email",
+        }
+
+    # Primitive types: return as-is
+    if obj is None or isinstance(obj, (bool, int, float)):
+        return obj
+    if isinstance(obj, str):
+        # avoid printing long secret-like strings fully
+        if len(obj) > 256:
+            return obj[:64] + "...<redacted>..." + obj[-64:]
+        return obj
+
+    # dicts: redact sensitive keys recursively
+    if isinstance(obj, dict):
+        redacted = {}
+        for k, v in obj.items():
+            if str(k) in keys_to_redact:
+                redacted[k] = "<REDACTED>"
+            else:
+                redacted[k] = _redact(v, keys_to_redact)
+        return redacted
+
+    # lists / tuples: redact elements
+    if isinstance(obj, (list, tuple)):
+        return type(obj)(_redact(v, keys_to_redact) for v in obj)
+
+    # fallback: represent object as string but avoid huge dumps
+    try:
+        s = str(obj)
+        if len(s) > 512:
+            return s[:256] + "...<redacted>..."
+        return s
+    except Exception:
+        return "<UNREPRABLE>"
+
+
+def _redact_topic(topic: str) -> str:
+    """
+    Redact sensitive information from MQTT topic strings.
+
+    Topics often contain MAC addresses or device unique identifiers, e.g.:
+    - cmd/52/navilink-04786332fca0/st/did
+    - cmd/52/navilink-04786332fca0/ctrl
+    - cmd/52/04786332fca0/ctrl
+    - or with colons/hyphens (04:78:63:32:fc:a0 or 04-78-63-32-fc-a0)
+
+    Args:
+        topic: MQTT topic string
+
+    Returns:
+        Topic with MAC addresses redacted
+    """
+    import re
+
+    # Redact navilink-<mac>
+    topic = re.sub(r"(navilink-)[0-9a-fA-F]{12}", r"\1REDACTED", topic)
+    # Redact bare 12-hex MACs (lower/upper)
+    topic = re.sub(r"\b[0-9a-fA-F]{12}\b", "REDACTED", topic)
+    # Redact colon-delimited MAC format (e.g., 04:78:63:32:fc:a0)
+    topic = re.sub(r"\b([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}\b", "REDACTED", topic)
+    # Redact hyphen-delimited MAC format (e.g., 04-78-63-32-fc-a0)
+    topic = re.sub(r"\b([0-9a-fA-F]{2}-){5}[0-9a-fA-F]{2}\b", "REDACTED", topic)
+    return topic
+
+
 @dataclass
 class MqttConnectionConfig:
     """Configuration for MQTT connection."""
@@ -155,6 +254,7 @@ class NavienMqttClient(EventEmitter):
         - error_cleared: Error code cleared (error_code)
         - connection_interrupted: Connection lost (error)
         - connection_resumed: Connection restored (return_code, session_present)
+        - reconnection_failed: Reconnection permanently failed after max attempts (attempt_count)
     """
 
     def __init__(
@@ -359,6 +459,10 @@ class NavienMqttClient(EventEmitter):
                 f"Failed to reconnect after {self.config.max_reconnect_attempts} attempts. "
                 "Manual reconnection required."
             )
+            # Stop all periodic tasks to reduce log noise
+            await self._stop_all_periodic_tasks()
+            # Emit event so users can take action
+            self._schedule_coroutine(self.emit("reconnection_failed", self._reconnect_attempts))
 
     async def _send_queued_commands(self):
         """
@@ -392,7 +496,9 @@ class NavienMqttClient(EventEmitter):
                 )
             except Exception as e:
                 failed_count += 1
-                _logger.error(f"Failed to send queued command to '{command.topic}': {e}")
+                _logger.error(
+                    f"Failed to send queued command to '{_redact_topic(command.topic)}': {e}"
+                )
                 # Re-queue if there's room
                 if len(self._command_queue) < self.config.max_queued_commands:
                     self._command_queue.append(command)
@@ -557,7 +663,7 @@ class NavienMqttClient(EventEmitter):
         try:
             # Parse JSON payload
             message = json.loads(payload.decode("utf-8"))
-            _logger.debug(f"Received message on topic '{topic}': {message}")
+            _logger.debug("Received message on topic: %s", topic)
 
             # Call registered handlers that match this topic
             # Need to match against subscription patterns with wildcards
@@ -659,7 +765,7 @@ class NavienMqttClient(EventEmitter):
             return packet_id
 
         except Exception as e:
-            _logger.error(f"Failed to subscribe to '{topic}': {e}")
+            _logger.error(f"Failed to subscribe to '{_redact_topic(topic)}': {e}")
             raise
 
     async def unsubscribe(self, topic: str):
@@ -689,7 +795,7 @@ class NavienMqttClient(EventEmitter):
             _logger.info(f"Unsubscribed from '{topic}'")
 
         except Exception as e:
-            _logger.error(f"Failed to unsubscribe from '{topic}': {e}")
+            _logger.error(f"Failed to unsubscribe from '{_redact_topic(topic)}': {e}")
             raise
 
     async def publish(
@@ -724,7 +830,6 @@ class NavienMqttClient(EventEmitter):
                 raise RuntimeError("Not connected to MQTT broker")
 
         _logger.debug(f"Publishing to topic: {topic}")
-        _logger.debug(f"Payload: {payload}")
 
         try:
             # Serialize to JSON
@@ -745,7 +850,26 @@ class NavienMqttClient(EventEmitter):
             return packet_id
 
         except Exception as e:
-            _logger.error(f"Failed to publish to '{topic}': {e}")
+            # Handle clean session cancellation gracefully
+            # Check exception type and name attribute for proper error identification
+            if (
+                isinstance(e, AwsCrtError)
+                and e.name == "AWS_ERROR_MQTT_CANCELLED_FOR_CLEAN_SESSION"
+            ):
+                _logger.warning(
+                    "Publish cancelled due to clean session. This is expected during reconnection."
+                )
+                # Queue the command if queue is enabled
+                if self.config.enable_command_queue:
+                    _logger.debug("Queuing command due to clean session cancellation")
+                    self._queue_command(topic, payload, qos)
+                    return 0  # Return 0 to indicate command was queued
+                # Otherwise, raise an error so the caller can handle the failure
+                raise RuntimeError(
+                    "Publish cancelled due to clean session and command queue is disabled"
+                )
+
+            _logger.error(f"Failed to publish to '{_redact_topic(topic)}': {e}")
             raise
 
     # Navien-specific convenience methods
@@ -1148,21 +1272,26 @@ class NavienMqttClient(EventEmitter):
 
         return await self.publish(topic, command)
 
-    async def set_dhw_mode(self, device: Device, mode_id: int) -> int:
+    async def set_dhw_mode(
+        self,
+        device: Device,
+        mode_id: int,
+        vacation_days: Optional[int] = None,
+    ) -> int:
         """
         Set DHW (Domestic Hot Water) operation mode.
 
         Args:
             device: Device object
-            mode_id: Mode ID (1=Heat Pump Only, 2=Electric Only, 3=Energy Saver, 4=High Demand)
-            device_type: Device type (52 for NWP500)
-            additional_value: Additional value from device info
+            mode_id: Mode ID (1=Heat Pump Only, 2=Electric Only, 3=Energy Saver,
+                4=High Demand, 5=Vacation)
+            vacation_days: Number of vacation days (required when mode_id == 5)
 
         Returns:
             Publish packet ID
 
         Note:
-            Valid selectable mode IDs are 1, 2, 3, and 4.
+            Valid selectable mode IDs are 1, 2, 3, 4, and 5 (vacation).
             Additional modes may appear in status responses:
             - 0: Standby (device in idle state)
             - 6: Power Off (device is powered off)
@@ -1172,7 +1301,19 @@ class NavienMqttClient(EventEmitter):
             - 2: Electric Only (least efficient, fastest recovery)
             - 3: Energy Saver (balanced, good default)
             - 4: High Demand (maximum heating capacity)
+            - 5: Vacation Mode (requires vacation_days parameter)
         """
+        if mode_id == OperationMode.VACATION.value:
+            if vacation_days is None:
+                raise ValueError("Vacation mode requires vacation_days (1-30)")
+            if not 1 <= vacation_days <= 30:
+                raise ValueError("vacation_days must be between 1 and 30")
+            param = [mode_id, vacation_days]
+        else:
+            if vacation_days is not None:
+                raise ValueError("vacation_days is only valid for vacation mode (mode 5)")
+            param = [mode_id]
+
         device_id = device.device_info.mac_address
         device_type = device.device_info.device_type
         additional_value = device.device_info.additional_value
@@ -1185,7 +1326,83 @@ class NavienMqttClient(EventEmitter):
             command=CMD_DHW_MODE,  # DHW mode control command (different from power commands)
             additional_value=additional_value,
             mode="dhw-mode",
-            param=[mode_id],
+            param=param,
+            paramStr="",
+        )
+        command["requestTopic"] = topic
+
+        return await self.publish(topic, command)
+
+    async def enable_anti_legionella(self, device: Device, period_days: int) -> int:
+        """Enable Anti-Legionella disinfection with a 1-30 day cycle.
+
+        This command has been confirmed through HAR analysis of the official Navien app.
+        When sent, the device responds with antiLegionellaUse=2 (enabled) and
+        antiLegionellaPeriod set to the specified value.
+
+        See docs/MQTT_MESSAGES.rst "Anti-Legionella Control" for the authoritative
+        command code (33554472) and expected payload format:
+        {"mode": "anti-leg-on", "param": [<period_days>], "paramStr": ""}
+
+        Args:
+            device: The device to control
+            period_days: Days between disinfection cycles (1-30)
+
+        Returns:
+            The message ID of the published command
+
+        Raises:
+            ValueError: If period_days is not in the valid range [1, 30]
+        """
+        if not 1 <= period_days <= 30:
+            raise ValueError("period_days must be between 1 and 30")
+
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl"
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_ANTI_LEGIONELLA_ENABLE,
+            additional_value=additional_value,
+            mode="anti-leg-on",
+            param=[period_days],
+            paramStr="",
+        )
+        command["requestTopic"] = topic
+
+        return await self.publish(topic, command)
+
+    async def disable_anti_legionella(self, device: Device) -> int:
+        """Disable the Anti-Legionella disinfection cycle.
+
+        This command has been confirmed through HAR analysis of the official Navien app.
+        When sent, the device responds with antiLegionellaUse=1 (disabled) while
+        antiLegionellaPeriod retains its previous value.
+
+        The correct command code is 33554471 (not 33554473 as previously assumed).
+
+        See docs/MQTT_MESSAGES.rst "Anti-Legionella Control" section for details.
+
+        Returns:
+            The message ID of the published command
+        """
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl"
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_ANTI_LEGIONELLA_DISABLE,
+            additional_value=additional_value,
+            mode="anti-leg-off",
+            param=[],
             paramStr="",
         )
         command["requestTopic"] = topic
@@ -1234,6 +1451,19 @@ class NavienMqttClient(EventEmitter):
 
         return await self.publish(topic, command)
 
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_DHW_TEMPERATURE,  # DHW temperature control command
+            additional_value=additional_value,
+            mode="dhw-temperature",
+            param=[temperature],
+            paramStr="",
+        )
+        command["requestTopic"] = topic
+
+        return await self.publish(topic, command)
+
     async def set_dhw_temperature_display(self, device: Device, display_temperature: int) -> int:
         """
         Set DHW target temperature using the DISPLAY value (what you see on device/app).
@@ -1256,6 +1486,150 @@ class NavienMqttClient(EventEmitter):
         message_temperature = display_temperature - 20
         return await self.set_dhw_temperature(device, message_temperature)
 
+    async def update_reservations(
+        self,
+        device: Device,
+        reservations: Sequence[dict[str, Any]],
+        *,
+        enabled: bool = True,
+    ) -> int:
+        """Update programmed reservations for temperature/mode changes."""
+        # See docs/MQTT_MESSAGES.rst "Reservation Management" for the
+        # command code (16777226) and the reservation object fields
+        # (enable, week, hour, min, mode, param).
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl/rsv/rd"
+
+        reservation_use = 1 if enabled else 2
+        reservation_payload = [dict(entry) for entry in reservations]
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_RESERVATION_MANAGEMENT,
+            additional_value=additional_value,
+            reservationUse=reservation_use,
+            reservation=reservation_payload,
+        )
+        command["requestTopic"] = topic
+        command["responseTopic"] = f"cmd/{device_type}/{self.config.client_id}/res/rsv/rd"
+
+        return await self.publish(topic, command)
+
+    async def request_reservations(self, device: Device) -> int:
+        """Request the current reservation program from the device."""
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl/rsv/rd"
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_RESERVATION_MANAGEMENT,
+            additional_value=additional_value,
+        )
+        command["requestTopic"] = topic
+        command["responseTopic"] = f"cmd/{device_type}/{self.config.client_id}/res/rsv/rd"
+
+        return await self.publish(topic, command)
+
+    async def configure_tou_schedule(
+        self,
+        device: Device,
+        controller_serial_number: str,
+        periods: Sequence[dict[str, Any]],
+        *,
+        enabled: bool = True,
+    ) -> int:
+        """Configure Time-of-Use pricing schedule via MQTT."""
+        # See docs/MQTT_MESSAGES.rst "TOU (Time of Use) Settings" for
+        # the command code (33554439) and TOU period fields
+        # (season, week, startHour, startMinute, endHour, endMinute,
+        #  priceMin, priceMax, decimalPoint).
+        if not controller_serial_number:
+            raise ValueError("controller_serial_number is required")
+        if not periods:
+            raise ValueError("At least one TOU period must be provided")
+
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl/tou/rd"
+
+        reservation_use = 1 if enabled else 2
+        reservation_payload = [dict(period) for period in periods]
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_TOU_SETTINGS,
+            additional_value=additional_value,
+            controllerSerialNumber=controller_serial_number,
+            reservationUse=reservation_use,
+            reservation=reservation_payload,
+        )
+        command["requestTopic"] = topic
+        command["responseTopic"] = f"cmd/{device_type}/{self.config.client_id}/res/tou/rd"
+
+        return await self.publish(topic, command)
+
+    async def request_tou_settings(
+        self,
+        device: Device,
+        controller_serial_number: str,
+    ) -> int:
+        """Request current Time-of-Use schedule from the device."""
+        if not controller_serial_number:
+            raise ValueError("controller_serial_number is required")
+
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl/tou/rd"
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=CMD_TOU_SETTINGS,
+            additional_value=additional_value,
+            controllerSerialNumber=controller_serial_number,
+        )
+        command["requestTopic"] = topic
+        command["responseTopic"] = f"cmd/{device_type}/{self.config.client_id}/res/tou/rd"
+
+        return await self.publish(topic, command)
+
+    async def set_tou_enabled(self, device: Device, enabled: bool) -> int:
+        """Quickly toggle Time-of-Use functionality without modifying the schedule."""
+        device_id = device.device_info.mac_address
+        device_type = device.device_info.device_type
+        additional_value = device.device_info.additional_value
+        device_topic = f"navilink-{device_id}"
+        topic = f"cmd/{device_type}/{device_topic}/ctrl"
+
+        command_code = CMD_TOU_ENABLE if enabled else CMD_TOU_DISABLE
+        mode = "tou-on" if enabled else "tou-off"
+
+        command = self._build_command(
+            device_type=device_type,
+            device_id=device_id,
+            command=command_code,
+            additional_value=additional_value,
+            mode=mode,
+            param=[],
+            paramStr="",
+        )
+        command["requestTopic"] = topic
+
+        return await self.publish(topic, command)
+
     async def request_energy_usage(self, device: Device, year: int, months: list[int]) -> int:
         """
         Request daily energy usage data for specified month(s).
@@ -1458,15 +1832,39 @@ class NavienMqttClient(EventEmitter):
                 f"(every {period_seconds}s)"
             )
 
+            # Track consecutive skips for throttled logging
+            consecutive_skips = 0
+
             while True:
                 try:
                     if not self._connected:
-                        _logger.warning(
-                            "Not connected, skipping %s request for %s",
-                            request_type.value,
-                            redacted_device_id,
-                        )
+                        consecutive_skips += 1
+                        # Log warning only on first skip and then every 10th skip to reduce noise
+                        if consecutive_skips == 1 or consecutive_skips % 10 == 0:
+                            _logger.warning(
+                                "Not connected, skipping %s request for %s (skipped %d time%s)",
+                                request_type.value,
+                                redacted_device_id,
+                                consecutive_skips,
+                                "s" if consecutive_skips > 1 else "",
+                            )
+                        else:
+                            _logger.debug(
+                                "Not connected, skipping %s request for %s",
+                                request_type.value,
+                                redacted_device_id,
+                            )
                     else:
+                        # Reset skip counter when connected
+                        if consecutive_skips > 0:
+                            _logger.info(
+                                "Reconnected, resuming %s requests for %s (had skipped %d)",
+                                request_type.value,
+                                redacted_device_id,
+                                consecutive_skips,
+                            )
+                            consecutive_skips = 0
+
                         # Send appropriate request type
                         if request_type == PeriodicRequestType.DEVICE_INFO:
                             await self.request_device_info(device)
@@ -1488,13 +1886,26 @@ class NavienMqttClient(EventEmitter):
                     )
                     break
                 except Exception as e:
-                    _logger.error(
-                        "Error in periodic %s request for %s: %s",
-                        request_type.value,
-                        redacted_device_id,
-                        e,
-                        exc_info=True,
-                    )
+                    # Handle clean session cancellation gracefully (expected during reconnection)
+                    # Check exception type and name attribute for proper error identification
+                    if (
+                        isinstance(e, AwsCrtError)
+                        and e.name == "AWS_ERROR_MQTT_CANCELLED_FOR_CLEAN_SESSION"
+                    ):
+                        _logger.debug(
+                            "Periodic %s request cancelled due to clean session for %s. "
+                            "This is expected during reconnection.",
+                            request_type.value,
+                            redacted_device_id,
+                        )
+                    else:
+                        _logger.error(
+                            "Error in periodic %s request for %s: %s",
+                            request_type.value,
+                            redacted_device_id,
+                            e,
+                            exc_info=True,
+                        )
                     # Continue despite errors
                     await asyncio.sleep(period_seconds)
 
@@ -1562,6 +1973,16 @@ class NavienMqttClient(EventEmitter):
                 + (f" (type={request_type.value})" if request_type else "")
             )
 
+    async def _stop_all_periodic_tasks(self) -> None:
+        """
+        Stop all periodic tasks.
+
+        This is called internally when reconnection fails permanently
+        to reduce log noise from tasks trying to send requests while disconnected.
+        """
+        # Delegate to public method with specific reason
+        await self.stop_all_periodic_tasks(_reason="connection failure")
+
     # Convenience methods
     async def start_periodic_device_info_requests(
         self, device: Device, period_seconds: float = 300.0
@@ -1621,19 +2042,24 @@ class NavienMqttClient(EventEmitter):
         """
         await self.stop_periodic_requests(device, PeriodicRequestType.DEVICE_STATUS)
 
-    async def stop_all_periodic_tasks(self) -> None:
+    async def stop_all_periodic_tasks(self, _reason: Optional[str] = None) -> None:
         """
         Stop all periodic request tasks.
 
         This is automatically called when disconnecting.
 
+        Args:
+            _reason: Internal parameter for logging context (e.g., "connection failure")
+
         Example:
             >>> await mqtt_client.stop_all_periodic_tasks()
         """
         if not self._periodic_tasks:
             return
 
-        _logger.info(f"Stopping {len(self._periodic_tasks)} periodic task(s)")
+        task_count = len(self._periodic_tasks)
+        reason_msg = f" due to {_reason}" if _reason else ""
+        _logger.info(f"Stopping {task_count} periodic task(s){reason_msg}")
 
         # Cancel all tasks
         for task in self._periodic_tasks.values():
@@ -1687,3 +2113,28 @@ class NavienMqttClient(EventEmitter):
             self._command_queue.clear()
             _logger.info(f"Cleared {count} queued command(s)")
         return count
+
+    async def reset_reconnect(self) -> None:
+        """
+        Reset reconnection state and trigger a new reconnection attempt.
+
+        This method resets the reconnection attempt counter and initiates
+        a new reconnection cycle. Useful for implementing custom recovery
+        logic after max reconnection attempts have been exhausted.
+
+        Example:
+            >>> # In a reconnection_failed event handler
+            >>> await mqtt_client.reset_reconnect()
+
+        Note:
+            This should typically only be called after a reconnection_failed
+            event, not during normal operation.
+        """
+        self._reconnect_attempts = 0
+        self._manual_disconnect = False
+        await self._start_reconnect_task()
+        count = len(self._command_queue)
+        if count > 0:
+            self._command_queue.clear()
+            _logger.info(f"Cleared {count} queued command(s)")
+        return count
